<?php
/*************************************/
/* Tunnel optimisé by CarpeDiem.fr   */
/*************************************/
/* Support :                         */
/* - Commercial : erwan@carpediem.fr */
/* - Tech : philippe@carpediem.fr    */
/*************************************/

require('config.php');

/**
 * Filter Incoming Data
 * @param  array  $post
 * @return array
 */
function filterInput(array $post = array())
{
    $args = array(
        'tracker' => array(
            'filter' => FILTER_SANITIZE_STRING,
            'flags' => FILTER_FLAG_STRIP_LOW|FILTER_FLAG_STRIP_HIGH
        ),
        'email' => FILTER_VALIDATE_EMAIL,
    );

    return array_filter(array_merge(array(
        'email' => false,
    ), (array) filter_var_array($post, $args)));

}

/**
 * Validate Inputs
 * @param  array  $inputs
 * @return array
 */
function validateInput(array $inputs = array())
{
    $errors = array();
    if (! isset($inputs['email'])) {
        $errors['email'] = "L'adresse mail est obligatoire.";
    }

    return $errors;
}

header('Content-type: application/json; charset=utf-8');

// Only POST datas alowed
if ('POST' != $_SERVER['REQUEST_METHOD']) {
    die(json_encode(array(
        'status' => 'errors',
        'errors' => array('method' => 'Request Method Not Supported'),
    )));
}

// Filters & validate POST datas
$inputs = filterInput($_POST);
$errors = validateInput($inputs);
if (count($errors)) {
    die(json_encode(array(
        'status' => 'errors',
        'errors' => $errors,
    )));
}

// Remote registering
$inputs['id'] = $config['id'];
if ( !empty($inputs['tracker']) ) {
    $inputs['tracker'] = 'trID_' . $inputs['tracker'] . '_trID_' . $config['tracker'] . '_tunOpt';
} else {
    $inputs['tracker'] = $config['tracker'] . '_tunOpt';
}
$inputs['id_mb'] = $config['id_mb'];
$inputs['ip'] = getClientIp();

$curl = curl_init();

curl_setopt_array(
    $curl,
    array(
        CURLOPT_URL => 'http://api.mykodial.com/user/',
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_TIMEOUT => 10,
        CURLOPT_POST => true,
        CURLOPT_POSTFIELDS => $inputs,
        CURLOPT_HTTPHEADER => array('Accept: application/json'),
        )
    );
$content = curl_exec($curl);

if (! curl_errno($curl)) {

    $info = curl_getinfo($curl);
    if (500 == $info['http_code']) {
        die(json_encode(array(
            'status' => 'errors',
            'errors' => array('method' => 'Server unavalaible'),
        )));
    } elseif (405 == $info['http_code']) {
        die(json_encode(array(
            'status' => 'errors',
            'errors' => array('method' => 'Request Method Not Supported'),
        )));
    } elseif (400 == $info['http_code']) {
        die(json_encode(array(
            'status' => 'errors',
            'errors' => array('email' => 'Adresse mail invalide'),
        )));
    } elseif (200 == $info['http_code']) {
        die($content);   
    }

} 

/**
 * Get client IP
 * param void
 * return $ip (string)
 **/
function getClientIp()
{

    $fields = array(
        'HTTP_CLIENT_IP',
        'HTTP_X_FORWARDED_FOR',
        'HTTP_X_FORWARDED',
        'HTTP_FORWARDED_FOR',
        'HTTP_FORWARDED',
        'REMOTE_ADDR',
        );

    foreach ($fields as $key) {
        if (isset($_SERVER[$key])) {
            $clientIp = $_SERVER[$key];
            return $_SERVER[$key];
        }
    }

    return '';

}

/**
 * Get external file
 * param $url (string)
 * return $content (string)
 **/
function getRemoteFileContent($url)
{

    if (! function_exists('curl_init')) {
        return file_get_contents($url);
    }

    $ch = curl_init();
    $args = array(
        CURLOPT_URL => $url,
        CURLOPT_TIMEOUT => 10,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_USERAGENT => "Mozilla/5.0 (Windows NT 6.0; WOW64; rv:21.0) Gecko/20130320 Firefox/21.0",
    );
    curl_setopt_array($ch, $args);

    $content = curl_exec($ch);

    curl_close($ch);

    return $content;

}